aboutsummaryrefslogtreecommitdiff
path: root/sound/adpcm.h
diff options
context:
space:
mode:
Diffstat (limited to 'sound/adpcm.h')
-rw-r--r--sound/adpcm.h36
1 files changed, 17 insertions, 19 deletions
diff --git a/sound/adpcm.h b/sound/adpcm.h
index 48d003ae78..46ccb582c3 100644
--- a/sound/adpcm.h
+++ b/sound/adpcm.h
@@ -42,6 +42,7 @@
namespace Audio {
class AudioStream;
+class RewindableAudioStream;
// There are several types of ADPCM encoding, only some are supported here
// For all the different encodings, refer to:
@@ -61,27 +62,24 @@ enum typesADPCM {
/**
* Takes an input stream containing ADPCM compressed sound data and creates
* an AudioStream from that.
*
* @param stream the SeekableReadStream from which to read the ADPCM data
* @param disposeAfterUse whether to delete the stream after use
* @param size how many bytes to read from the stream (0 = all)
* @param type the compression type used
* @param rate the sampling rate (default = 22050)
* @param channels the number of channels (default = 2)
* @param blockAlign block alignment ??? (default = 0)
* @param numLoop how many types the sounds should loop, 0 for infinite loop (default = 1)
* @return a new AudioStream, or NULL, if an error occured
*/
-AudioStream *makeADPCMStream(
- Common::SeekableReadStream *stream,
- bool disposeAfterUse,
- uint32 size,
- typesADPCM type,
- int rate = 22050,
- int channels = 2,
- uint32 blockAlign = 0,
- uint numLoops = 1);
+RewindableAudioStream *makeADPCMStream(
+ Common::SeekableReadStream *stream,
+ bool disposeAfterUse,
+ uint32 size, typesADPCM type,
+ int rate = 22050,
+ int channels = 2,
+ uint32 blockAlign = 0);
} // End of namespace Audio
@@ -61,27 +62,24 @@ enum typesADPCM {
/**
* Takes an input stream containing ADPCM compressed sound data and creates
- * an AudioStream from that.
+ * an RewindableAudioStream from that.
*
@@ -61,27 +62,24 @@ enum typesADPCM {
*
- * @param stream the SeekableReadStream from which to read the ADPCM data
- * @param disposeAfterUse whether to delete the stream after use
- * @param size how many bytes to read from the stream (0 = all)
- * @param type the compression type used
- * @param rate the sampling rate (default = 22050)
- * @param channels the number of channels (default = 2)
- * @param blockAlign block alignment ??? (default = 0)
- * @param numLoop how many types the sounds should loop, 0 for infinite loop (default = 1)
- * @return a new AudioStream, or NULL, if an error occured
+ * @param stream the SeekableReadStream from which to read the ADPCM data
+ * @param disposeAfterUse whether to delete the stream after use
+ * @param size how many bytes to read from the stream (0 = all)
+ * @param type the compression type used
+ * @param rate the sampling rate
+ * @param channels the number of channels
+ * @param blockAlign block alignment ???
+ * @return a new RewindableAudioStream, or NULL, if an error occured
*/